@@ -1,7 +1,4 @@
 <?php
-/** WordPress's config file **/
-/** http://wordpress.org/   **/
-
 // ** MySQL settings ** //
 define('DB_NAME', 'wordpress');     // The name of the database
 define('DB_USER', 'username');     // Your MySQL username
@@ -9,7 +6,6 @@ define('DB_PASSWORD', 'password'); // ...and password
 define('DB_HOST', 'localhost');     // 99% chance you won't need to change this value
 
 // Change the prefix if you want to have multiple blogs in a single database.
-
 $table_prefix  = 'wp_';   // example: 'wp_' or 'b2' or 'mylogin_'
 
 // Change this to localize WordPress.  A corresponding MO file for the
@@ -20,13 +16,6 @@ define ('WPLANG', '');
 
 /* Stop editing */
 
-$server = DB_HOST;
-$loginsql = DB_USER;
-$passsql = DB_PASSWORD;
-$base = DB_NAME;
-
 define('ABSPATH', dirname(__FILE__).'/');
-
-// Get everything else
 require_once(ABSPATH.'wp-settings.php');
-?>
+?>
\ No newline at end of file
