@@ -14,7 +14,7 @@
 <!-- Gorgeous design by Michael Heilemann - http://binarybonsai.com/kubrick/ -->
 <?php /* "Just what do you think you're doing Dave?" */ ?>
 
-		<?php do_action('wp_footer'); ?>
+		<?php wp_footer(); ?>
 
 </body>
 </html>
\ No newline at end of file
